"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Base class for all connected service definitions.
 */
class ConnectedService {
    /**
     * Creates a new ConnectedService instance.
     * @param source (Optional) JSON based service definition.
     * @param type (Optional) type of service being defined.
     */
    constructor(source = {}, type) {
        this.type = type;
        Object.assign(this, source);
        if (type) {
            this.type = type;
        }
    }
    /**
     * Returns a JSON based version of the model for saving to disk.
     */
    toJSON() {
        return Object.assign({}, this);
    }
    /**
     * Encrypt properties on this service.
     * @param secret Secret to use to encrypt the keys in this service.
     * @param encryptString Function called to encrypt an individual value.
     */
    encrypt(secret, encryptString) {
        // noop
    }
    /**
     * Decrypt properties on this service.
     * @param secret Secret to use to decrypt the keys in this service.
     * @param decryptString Function called to decrypt an individual value.
     */
    decrypt(secret, decryptString) {
        // noop
    }
}
exports.ConnectedService = ConnectedService;
//# sourceMappingURL=connectedService.js.map